#!/usr/bin/ruby
require 'resolv'

class DNSMonkey
  #
  # @return [Resolv::DNS]
  #
  attr_reader :resolver

  def initialize(resolver: Resolv::DNS.new)
    @resolver = resolver
  end

  #
  # @return [String, nil] returns name of A record or nil if A record does not
  #   exist
  #
  def a_record_name(name)
    return a_record_name(resolv_cname_record(name).name) if cname_record?(name)
    return name.to_s if a_record?(name)
  end

  private

  def resolv_a_record(name)
    resolver.getresource(name, Resolv::DNS::Resource::IN::A)
  end

  def resolv_cname_record(name)
    resolver.getresource(name, Resolv::DNS::Resource::IN::CNAME)
  end

  def cname_record?(name)
    resolv_cname_record(name)
    true
  rescue Resolv::ResolvError
    false
  end

  def a_record?(name)
    resolv_a_record(name)
    true
  rescue Resolv::ResolvError
    false
  end
end
